@@ -37,6 +37,8 @@
 
 namespace tntdb
 {
+  class RowReader;
+
   /**
    * Row represents a row, which is fetched from the database.
    */
@@ -66,16 +68,17 @@ namespace tntdb
       Value getValue(size_type field_num) const
         { return row->getValueByNumber(field_num); }
       /// Returns the value-object by name.
-      /// Note that this is less effective than fetching by number
       Value getValue(const std::string& field_name) const
         { return row->getValueByName(field_name); }
       /// Returns the field_num's value-object.
       Value operator[] (size_type field_num) const
         { return row->getValueByNumber(field_num); }
       /// Returns the value-object by name.
-      /// Note that this is less effective than fetching by number
       Value operator[] (const std::string& field_name) const
         { return row->getValueByName(field_name); }
+      /// Returns the name of the field_num's column
+      std::string getName(size_type field_num) const
+        { return row->getColumnName(field_num); }
 
       /// Return true, if the specified value is null.
       bool isNull(size_type field_num) const
@@ -92,10 +95,18 @@ namespace tntdb
 
       bool getBool(size_type field_num) const
         { return getValue(field_num).getBool(); }
+      short getShort(size_type field_num) const
+        { return getValue(field_num).getShort(); }
       int getInt(size_type field_num) const
         { return getValue(field_num).getInt(); }
+      long getLong(size_type field_num) const
+        { return getValue(field_num).getLong(); }
+      unsigned short getUnsignedShort(size_type field_num) const
+        { return getValue(field_num).getUnsignedShort(); }
       unsigned getUnsigned(size_type field_num) const
         { return getValue(field_num).getUnsigned(); }
+      unsigned long getUnsignedLong(size_type field_num) const
+        { return getValue(field_num).getUnsignedLong(); }
       int32_t getInt32(size_type field_num) const
         { return getValue(field_num).getInt32(); }
       uint32_t getUnsigned32(size_type field_num) const
@@ -131,8 +142,12 @@ namespace tntdb
         { return getValue(field_name).getBool(); }
       int getInt(const std::string& field_name) const
         { return getValue(field_name).getInt(); }
+      long getLong(const std::string& field_name) const
+        { return getValue(field_name).getLong(); }
       unsigned getUnsigned(const std::string& field_name) const
         { return getValue(field_name).getUnsigned(); }
+      unsigned long getUnsignedLong(const std::string& field_name) const
+        { return getValue(field_name).getUnsignedLong(); }
       int32_t getInt32(const std::string& field_name) const
         { return getValue(field_name).getInt32(); }
       uint32_t getUnsigned32(const std::string& field_name) const
@@ -178,6 +193,9 @@ namespace tntdb
       bool operator!() const         { return !row; }
       /// Returns the actual implementation-class.
       const IRow* getImpl() const    { return &*row; }
+
+      /// Instantiates a tntdb::RowReader with the passed initial column counter.
+      RowReader reader(size_type n = 0) const;
   };
 }
 
