@@ -1,16 +1,26 @@
-/* 
+/*
  * Copyright (C) 2005 Tommi Maekitalo
- *
+ * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- *
+ * 
+ * As a special exception, you may use this file as part of a free
+ * software library without restriction. Specifically, if other files
+ * instantiate templates or use macros or inline functions from this
+ * file, or you compile this file and link it with other files to
+ * produce an executable, this file does not by itself cause the
+ * resulting executable to be covered by the GNU General Public
+ * License. This exception does not however invalidate any other
+ * reasons why the executable file might be covered by the GNU Library
+ * General Public License.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -139,24 +149,21 @@ namespace tntdb
         { return !operator==(dt); }
 
       bool operator< (const Datetime& dt) const
-      { return year < dt.year
-            || year == dt.year
-             && ( month < dt.month
-               || month == dt.month
-                && ( day < dt.day
-                  || day == dt.day
-                   && ( hour < dt.hour
-                     || hour == dt.hour
-                      && ( minute < dt.minute
-                        || minute == dt.minute
-                         && ( second < dt.second
-                           || second == dt.second
-                            && millis < dt.millis
-                            )
-                         )
-                       )
-                    )
-                ); }
+      {
+        return year   < dt.year   ? true
+             : year   > dt.year   ? false
+             : month  < dt.month  ? true
+             : month  > dt.month  ? false
+             : day    < dt.day    ? true
+             : day    > dt.day    ? false
+             : hour   < dt.hour   ? true
+             : hour   > dt.hour   ? false
+             : minute < dt.minute ? true
+             : minute > dt.minute ? false
+             : second < dt.second ? true
+             : second > dt.second ? false
+             : millis < dt.millis;
+      }
 
       bool operator> (const Datetime& dt) const
         { return dt < *this; }
