@@ -32,6 +32,7 @@
 #include <tntdb/iface/istatement.h>
 #include <tntdb/iface/irow.h>
 #include <tntdb/mysql/bindvalues.h>
+#include <tntdb/mysql/impl/boundrow.h>
 #include <tntdb/connection.h>
 #include <map>
 
@@ -49,9 +50,12 @@ namespace tntdb
         hostvarMapType hostvarMap;
         MYSQL* mysql;
         MYSQL_STMT* stmt;
-        MYSQL_RES* metadata;
+        MYSQL_FIELD* fields;
+        unsigned field_count;
+        cxxtools::SmartPtr<BoundRow> rowPtr;
 
-        cxxtools::SmartPtr<IRow> fetchRow(MYSQL_FIELD* fields, unsigned field_count);
+        cxxtools::SmartPtr<BoundRow> getRow();
+        cxxtools::SmartPtr<IRow> fetchRow();
 
       public:
         Statement(const tntdb::Connection& conn, MYSQL* mysql,
@@ -63,8 +67,10 @@ namespace tntdb
         void clear();
         void setNull(const std::string& col);
         void setBool(const std::string& col, bool data);
+        void setShort(const std::string& col, short data);
         void setInt(const std::string& col, int data);
         void setLong(const std::string& col, long data);
+        void setUnsignedShort(const std::string& col, unsigned short data);
         void setUnsigned(const std::string& col, unsigned data);
         void setUnsignedLong(const std::string& col, unsigned long data);
         void setInt32(const std::string& col, int32_t data);
@@ -100,8 +106,6 @@ namespace tntdb
         /// If there is already a statement, the offered statement is closed.
         void putback(MYSQL_STMT* stmt);
 
-        MYSQL_RES* getMetadata();
-        void freeMetadata();
         MYSQL_FIELD* getFields();
         unsigned getFieldCount();
     };
