@@ -64,9 +64,16 @@ namespace tntdb
             Blob blob;
             Number number;
 
+            const char* boundPtr;
+            int boundType;
+            unsigned boundLength;
+
             Bind()
               : ptr(0),
-                indicator(0)
+                indicator(0),
+                boundPtr(0),
+                boundType(0),
+                boundLength(0)
               { }
             void setData(const std::string& value)
             {
@@ -103,8 +110,10 @@ namespace tntdb
         void clear();
         void setNull(const std::string& col);
         void setBool(const std::string& col, bool data);
+        void setShort(const std::string& col, short data);
         void setInt(const std::string& col, int data);
         void setLong(const std::string& col, long data);
+        void setUnsignedShort(const std::string& col, unsigned short data);
         void setUnsigned(const std::string& col, unsigned data);
         void setUnsignedLong(const std::string& col, unsigned long data);
         void setInt32(const std::string& col, int32_t data);
