@@ -46,6 +46,7 @@ namespace tntdb
     {
         OCIDefine* defp;
         OCIParam* paramp;
+        OCIError* errhp;
         ub2 len;
         ub2 type;
         ub2 nullind;
@@ -69,8 +70,10 @@ namespace tntdb
 
         virtual bool isNull() const;
         virtual bool getBool() const;
+        virtual short getShort() const;
         virtual int getInt() const;
         virtual long getLong() const;
+        virtual unsigned short getUnsignedShort() const;
         virtual unsigned getUnsigned() const;
         virtual unsigned long getUnsignedLong() const;
         virtual int32_t getInt32() const;
