@@ -60,8 +60,10 @@ namespace tntdb
         virtual void clear();
         virtual void setNull(const std::string& col);
         virtual void setBool(const std::string& col, bool data);
+        virtual void setShort(const std::string& col, short data);
         virtual void setInt(const std::string& col, int data);
         virtual void setLong(const std::string& col, long data);
+        virtual void setUnsignedShort(const std::string& col, unsigned short data);
         virtual void setUnsigned(const std::string& col, unsigned data);
         virtual void setUnsignedLong(const std::string& col, unsigned long data);
         virtual void setInt32(const std::string& col, int32_t data);
