@@ -36,28 +36,13 @@
 #include <map>
 #include "config.h"
 
-#ifdef WITH_STATIC_POSTGRESQL
-# include <tntdb/postgresql/impl/connectionmanager.h>
-#endif
-
-#ifdef WITH_STATIC_MYSQL
-# include <tntdb/mysql/impl/connectionmanager.h>
-#endif
-
-#ifdef WITH_STATIC_SQLITE
-# include <tntdb/sqlite/impl/connectionmanager.h>
-#endif
-
-#ifdef WITH_STATIC_ORACLE
-# include <tntdb/oracle/connectionmanager.h>
-#endif
-
 log_define("tntdb.connect")
 
 namespace tntdb
 {
   typedef std::map<std::string, LibraryManager> librariesType;
   static librariesType libraries;
+  static cxxtools::Mutex mutex;
 
   Connection connect(const std::string& url)
   {
@@ -65,36 +50,15 @@ namespace tntdb
 
     std::string::size_type n = url.find(':');
     if (n == std::string::npos)
-#ifdef WITH_STATIC_POSTGRESQL
-      return connectionManager_postgresql.connect(url);
-#elif WITH_STATIC_MYSQL
-      return connectionManager_mysql.connect(url);
-#elif WITH_STATIC_SQLITE
-      return connectionManager_sqlite.connect(url);
-#elif WITH_STATIC_ORACLE
-      return connectionManager_oracle.connect(url);
-#else
       throw Error("invalid dburl \"" + url + '"');
-#endif
 
     std::string driverName =  url.substr(0, n);
-#ifdef WITH_STATIC_POSTGRESQL
-    if (driverName == "postgresql")
-      return connectionManager_postgresql.connect(url.substr(n + 1));
-#elif WITH_STATIC_MYSQL
-    if (driverName == "mysql")
-      return connectionManager_mysql.connect(url.substr(n + 1));
-#elif WITH_STATIC_SQLITE
-    if (driverName == "sqlite")
-      return connectionManager_sqlite.connect(url.substr(n + 1));
-#elif WITH_STATIC_ORACLE
-    if (driverName == "oracle")
-      return connectionManager_oracle.connect(url.substr(n + 1));
-#endif
 
     std::string libraryUrl = url.substr(n + 1);
     log_debug("driver \"" << driverName << "\" url=\"" << libraryUrl << '"');
 
+    cxxtools::MutexLock lock(mutex);
+
     // lookup library-manager
     LibraryManager libraryManager;
     librariesType::const_iterator it = libraries.find(driverName);
@@ -106,6 +70,8 @@ namespace tntdb
     else
       libraryManager = it->second;
 
+    lock.unlock();
+
     return libraryManager.connect(libraryUrl);
   }
 
