@@ -49,7 +49,7 @@ namespace tntdb
       BindMapType::iterator it = bindMap.find(col);
       if (it == bindMap.end())
         it = bindMap.insert(BindMapType::value_type(col, new Bind())).first;
-      return it->second;
+      return it->second.getPointer();
     }
 
     Statement::Statement(Connection* conn_, const std::string& query_)
@@ -582,7 +582,7 @@ namespace tntdb
 
     tntdb::Result Statement::select()
     {
-      return tntdb::Result(new Result(this));
+      return tntdb::Result(new Result(this, 64));
     }
 
     tntdb::Row Statement::selectRow()
