@@ -32,9 +32,9 @@
 #include <tntdb/postgresql/error.h>
 #include <tntdb/result.h>
 #include <tntdb/statement.h>
+#include <cxxtools/convert.h>
 #include <cxxtools/log.h>
 #include <new>
-#include <sstream>
 #include <poll.h>
 
 log_define("tntdb.postgresql.connection")
@@ -44,7 +44,8 @@ namespace tntdb
   namespace postgresql
   {
     Connection::Connection(const char* conninfo)
-      : transactionActive(0)
+      : transactionActive(0),
+        stmtCounter(0)
     {
       log_debug("PQconnectdb(\"" << conninfo << "\")");
 
@@ -80,13 +81,19 @@ namespace tntdb
     void Connection::commitTransaction()
     {
       if (transactionActive == 0 || --transactionActive == 0)
+      {
         execute("COMMIT");
+        deallocateStatements();
+      }
     }
 
     void Connection::rollbackTransaction()
     {
       if (transactionActive == 0 || --transactionActive == 0)
+      {
         execute("ROLLBACK");
+        deallocateStatements();
+      }
     }
 
     Connection::size_type Connection::execute(const std::string& query)
@@ -101,9 +108,9 @@ namespace tntdb
         throw PgSqlError(query, "PQexec", result, true);
       }
 
-      std::istringstream tuples(PQcmdTuples(result));
-      Connection::size_type ret = 0;
-      tuples >> ret;
+      std::string t = PQcmdTuples(result);
+      Connection::size_type ret = t.empty() ? 0
+                                            : cxxtools::convert<Connection::size_type>(t);
 
       log_debug("PQclear(" << result << ')');
       PQclear(result);
@@ -199,7 +206,7 @@ namespace tntdb
 
     long Connection::lastInsertId(const std::string& name)
     {
-      long ret;
+      long ret = 0;
 
       if (name.empty())
       {
@@ -224,5 +231,48 @@ namespace tntdb
       return ret;
     }
 
+    void Connection::deallocateStatement(const std::string& stmtName)
+    {
+      // Delay deallocation since a postgresql fail to execute anything including
+      // deallocate statements when a failed transaction is active.
+
+      stmtsToDeallocate.push_back(stmtName);
+      if (transactionActive == 0)
+        deallocateStatements();
+    }
+
+    void Connection::deallocateStatements()
+    {
+      for (std::vector<std::string>::size_type n = 0; n < stmtsToDeallocate.size(); ++n)
+      {
+        std::string sql = "DEALLOCATE " + stmtsToDeallocate[n];
+
+        log_debug("PQexec(" << getPGConn() << ", \"" << sql << "\")");
+        PGresult* result = PQexec(getPGConn(), sql.c_str());
+
+        if (isError(result))
+          log_error("error deallocating statement: " << PQresultErrorMessage(result));
+
+        log_debug("PQclear(" << result << ')');
+        PQclear(result);
+      }
+
+      stmtsToDeallocate.clear();
+    }
+
+    void Connection::lockTable(const std::string& tablename, bool exclusive)
+    {
+      std::string query = "LOCK TABLE ";
+      query += tablename;
+      query += exclusive ? " IN ACCESS EXCLUSIVE MODE" : " IN SHARE MODE";
+      log_debug("execute(\"" << query << "\")");
+
+      PGresult* result = PQexec(conn, query.c_str());
+      if (isError(result))
+      {
+        log_error(PQresultErrorMessage(result));
+        throw PgSqlError(query, "PQexec", result, true);
+      }
+    }
   }
 }
