@@ -45,6 +45,7 @@ namespace tntdb
   namespace sqlite
   {
     Connection::Connection(const char* conninfo)
+      : transactionActive(0)
     {
       log_debug("sqlite3_open(\"" << conninfo << "\")");
       int errcode = ::sqlite3_open(conninfo, &db);
@@ -53,6 +54,11 @@ namespace tntdb
         throw Execerror("sqlite3_open", db, errcode);
 
       log_debug("sqlite3 = " << db);
+
+      log_debug("sqlite3_busy_timeout(\"" << db << "\", 60000)");
+      errcode = ::sqlite3_busy_timeout(db, 60000);
+      if (errcode != SQLITE_OK)
+        throw Execerror("sqlite3_busy_timeout", db, errcode);
     }
 
     Connection::~Connection()
@@ -68,27 +74,35 @@ namespace tntdb
 
     void Connection::beginTransaction()
     {
-      execute("BEGIN TRANSACTION");
+      if (transactionActive == 0)
+        execute("BEGIN IMMEDIATE TRANSACTION");
+      ++transactionActive;
     }
 
     void Connection::commitTransaction()
     {
-      // Statement handles are invalidated at transaction end, therefore we
-      // release all cached statements here.
-      // The problem still remains since the application might preserve a
-      // statement handle, which can't be released here.
-      clearStatementCache();
-      execute("COMMIT TRANSACTION");
+      if (transactionActive == 0 || --transactionActive == 0)
+      {
+        // Statement handles are invalidated at transaction end, therefore we
+        // release all cached statements here.
+        // The problem still remains since the application might preserve a
+        // statement handle, which can't be released here.
+        clearStatementCache();
+        execute("COMMIT TRANSACTION");
+      }
     }
 
     void Connection::rollbackTransaction()
     {
-      // Statement handles are invalidated at transaction end, therefore we
-      // release all cached statements here.
-      // The problem still remains since the application might preserve a
-      // statement handle, which can't be released here.
-      clearStatementCache();
-      execute("ROLLBACK TRANSACTION");
+      if (transactionActive == 0 || --transactionActive == 0)
+      {
+        // Statement handles are invalidated at transaction end, therefore we
+        // release all cached statements here.
+        // The problem still remains since the application might preserve a
+        // statement handle, which can't be released here.
+        clearStatementCache();
+        execute("ROLLBACK TRANSACTION");
+      }
     }
 
     Connection::size_type Connection::execute(const std::string& query)
@@ -137,5 +151,12 @@ namespace tntdb
     {
       return static_cast<int>(sqlite3_last_insert_rowid(db));
     }
+
+    void Connection::lockTable(const std::string& tablename, bool exclusive)
+    {
+      // nothing to do - the database is locked by the exclusive transaction
+      // already
+    }
+
   }
 }
